<?php
/*
Plugin Name: Pixabay Image Picker
Description: Pixabay Image Picker with searchbox in edit post section.
Version: 1.0
Requires at least: 5.2
Requires PHP:      7.2
Author: Daniel Wom
Author URI: https://daniel-wom.de/
License: GPL v2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/

// Create settings page for adding the API key
function pixabay_image_picker_settings_page() {
	add_menu_page('Pixabay Image Picker Settings', 'Pixabay Image Picker', 'manage_options', 'pixabay-image-picker-settings', 'pixabay_image_picker_settings_page_html', '', 200);
}
add_action('admin_menu', 'pixabay_image_picker_settings_page');

function pixabay_image_picker_settings_page_html() {
	// check user capabilities
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}
	
	// show error/update messages
    settings_errors( 'pixabay_image_picker_messages' );
    ?>
    <div class="wrap">
        <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
        <form action="options.php" method="post">
            <?php
            // output security fields for the registered setting "pixabay_image_picker"
            settings_fields( 'pixabay_image_picker' );
            // output setting sections and their fields
            // (sections are registered for "pixabay_image_picker", each field is registered to a specific section)
            do_settings_sections( 'pixabay_image_picker' );
            // output save settings button
            submit_button( 'Save Settings' );
            ?>
        </form>
    </div>
    <?php
}

// Register settings
function pixabay_image_picker_settings() {
	register_setting( 'pixabay_image_picker', 'pixabay_image_picker_options', 'pixabay_image_picker_options_sanitize' );
 
	add_settings_section(
		'pixabay_image_picker_section_api',
		'API Settings',
		'pixabay_image_picker_section_api_cb',
		'pixabay_image_picker'
	);
   
	add_settings_field(
		'pixabay_image_picker_field_api',
		'API Key',
		'pixabay_image_picker_field_api_cb',
		'pixabay_image_picker',
		'pixabay_image_picker_section_api'
	);
}
add_action( 'admin_init', 'pixabay_image_picker_settings' );
 
// Section callback
function pixabay_image_picker_section_api_cb() {
	echo '<p>Enter your Pixabay API key below.</p>';
}
 
// Field callback
function pixabay_image_picker_field_api_cb() {
	// get the value of the setting we've registered with register_setting()
	$options = get_option( 'pixabay_image_picker_options' );
	// output the field
	?>
	<input type="text" name="pixabay_image_picker_options[pixabay_image_picker_field_api]" value="<?php echo $options['pixabay_image_picker_field_api']; ?>">
	<?php
}

// Sanitize and validate
function pixabay_image_picker_options_sanitize( $options ) {
	// If API key is present, sanitize it
	if ( ! empty( $options['pixabay_image_picker_field_api'] ) ) {
		$options['pixabay_image_picker_field_api'] = sanitize_text_field( $options['pixabay_image_picker_field_api'] );
	}
	 
	// Return sanitized options
	return $options;
}

// Add Pixabay Image Picker to Edit Post screen
function pixabay_image_picker_add_box() {
	add_meta_box(
		'pixabay_image_picker_select_image',
		'Pixabay Image Picker',
		'pixabay_image_picker_select_image_cb',
		'post',
		'side',
		'high'
	);
}
add_action( 'add_meta_boxes', 'pixabay_image_picker_add_box' );
 
// Output the Pixabay Image Picker
function pixabay_image_picker_select_image_cb( $post ) {
	// Get the API key
	$options = get_option( 'pixabay_image_picker_options' );
	$api_key = $options['pixabay_image_picker_field_api'];
	
	// Output markup
	?>
	<div id="pixabay_image_picker">
		<input type="text" id="pixabay_image_picker_search">
		<input type="button" id="pixabay_image_picker_search_button" value="Suchen">
		<ul id="pixabay_image_picker_results" style="overflow:auto;max-height:400px;"></ul>
		<input type="hidden" name="pixabay_image_picker_image_id" id="pixabay_image_picker_image_id" value="<?php echo $post_thumbnail_id; ?>">
	</div>
	
	<script>
		// Get the API key
		var pixabay_image_picker_api_key = '<?php echo $api_key; ?>';
		
		// Search button click event
		jQuery( '#pixabay_image_picker_search_button' ).click( function() {
			// Get the search term
			var search_term = jQuery( '#pixabay_image_picker_search' ).val();
			
			// Make the API call
			jQuery.ajax( {
				url: 'https://pixabay.com/api/?key=' + pixabay_image_picker_api_key + '&q=' + search_term + '&image_type=all',
				dataType: 'json',
				success: function( data ) {
					// Clear previous search results
					jQuery( '#pixabay_image_picker_results' ).html( '' );
					
					// Loop through the results
					jQuery.each( data.hits, function( key, hit ) {
						// Create the list item
						var li = jQuery( '<li>' ).html( '<img src="' + hit.largeImageURL + '" title="' + hit.tags + '" style="max-width:100%;"><span>Pixabay/' + hit.user + '</span>' );
						
						// Store the image ID in the list item
						li.attr( 'data-id', hit.id ); 
						
						// Append the list item to the list
						jQuery( '#pixabay_image_picker_results' ).append( li );
					} );
				}
			} );
		} );
	</script>
	<?php
}


